# CreateModelDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**type** | **str** |  | 
**outcome_type** | **str** |  | [optional] 
**feature_store** | **str** |  | 
**description** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**project_id** | **str** |  | 
**children_last_updated_at** | **datetime** |  | [optional] 
**children_last_updated_by** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

